@@ -1,22 +1,23 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright © 2009-2010 Pierre Raybaut
+# Copyright © 2009-2011 Pierre Raybaut
 # Licensed under the terms of the MIT License
 # (see spyderlib/__init__.py for details)
 
 """Qt utilities"""
 
+import os, re
 import os.path as osp
-import os, webbrowser
 
 from spyderlib.qt.QtGui import (QAction, QStyle, QWidget, QIcon, QApplication,
                                 QLabel, QVBoxLayout, QHBoxLayout, QLineEdit,
                                 QKeyEvent, QMenu, QKeySequence, QToolButton)
-from spyderlib.qt.QtCore import (SIGNAL, QVariant, QObject, Qt, QLocale,
-                                 QTranslator, QLibraryInfo)
+from spyderlib.qt.QtCore import (SIGNAL, QObject, Qt, QLocale, QTranslator,
+                                 QLibraryInfo)
+from spyderlib.qt.compat import to_qvariant, from_qvariant
 
 # Local import
-from spyderlib.config import get_icon, DATA_PATH, get_spyderplugins, PLUGIN_PATH
+from spyderlib.config import get_icon
 from spyderlib.utils import programs
 
 # Note: How to redirect a signal from widget *a* to widget *b* ?
@@ -29,36 +30,49 @@ from spyderlib.utils import programs
 #    self.connect(self.listwidget, SIGNAL('option_changed'),
 #                 lambda *args: self.emit(SIGNAL('option_changed'), *args))
 
+
 def qapplication(translate=True):
-    """
-    Return QApplication instance
-    Creates it if it doesn't already exist
-    """
+    """Return QApplication instance
+    Creates it if it doesn't already exist"""
     app = QApplication.instance()
     if not app:
-        app = QApplication([])
+        # Set Application name for Gnome 3
+        # https://groups.google.com/forum/#!topic/pyside/24qxvwfrRDs
+        app = QApplication(['Spyder'])
     if translate:
         install_translator(app)
     return app
 
+def file_uri(fname):
+    """Select the right file uri scheme according to the operating system"""
+    if os.name == 'nt':
+        # Local file
+        if re.search(r'^[a-zA-Z]:', fname):
+            return 'file:///' + fname
+        # UNC based path
+        else:
+            return 'file://' + fname
+    else:
+        return 'file://' + fname
+
 QT_TRANSLATOR = None
 def install_translator(qapp):
     """Install Qt translator to the QApplication instance"""
     global QT_TRANSLATOR
     if QT_TRANSLATOR is None:
-        locale = QLocale.system().name()
-        # Qt-specific translator
         qt_translator = QTranslator()
-        paths = QLibraryInfo.location(QLibraryInfo.TranslationsPath)
-        if qt_translator.load("qt_"+locale, paths):
+        if qt_translator.load("qt_"+QLocale.system().name(),
+                      QLibraryInfo.location(QLibraryInfo.TranslationsPath)):
             QT_TRANSLATOR = qt_translator # Keep reference alive
     if QT_TRANSLATOR is not None:
         qapp.installTranslator(QT_TRANSLATOR)
 
+
 def keybinding(attr):
     """Return keybinding"""
     ks = getattr(QKeySequence, attr)
-    return QKeySequence.keyBindings(ks)[0].toString()
+    return from_qvariant(QKeySequence.keyBindings(ks)[0], str)
+
 
 def _process_mime_path(path, extlist):
     if path.startswith(r"file://"):
@@ -75,6 +89,7 @@ def _process_mime_path(path, extlist):
         if extlist is None or osp.splitext(path)[1] in extlist:
             return path
 
+
 def mimedata2url(source, extlist=None):
     """
     Extract url list from MIME data
@@ -94,15 +109,18 @@ def mimedata2url(source, extlist=None):
     if pathlist:
         return pathlist
 
+
 def keyevent2tuple(event):
     """Convert QKeyEvent instance into a tuple"""
     return (event.type(), event.key(), event.modifiers(), event.text(),
             event.isAutoRepeat(), event.count())
+
     
 def tuple2keyevent(past_event):
     """Convert tuple into a QKeyEvent instance"""
     return QKeyEvent(*past_event)
 
+
 def restore_keyevent(event):
     if isinstance(event, tuple):
         _, key, modifiers, text, _, _ = event
@@ -115,6 +133,7 @@ def restore_keyevent(event):
     shift = modifiers & Qt.ShiftModifier
     return event, text, key, ctrl, shift
 
+
 def create_toolbutton(parent, text=None, shortcut=None, icon=None, tip=None,
                       toggled=None, triggered=None,
                       autoraise=True, text_beside_icon=False):
@@ -140,6 +159,7 @@ def create_toolbutton(parent, text=None, shortcut=None, icon=None, tip=None,
         button.setShortcut(shortcut)
     return button
 
+
 def action2button(action, autoraise=True, text_beside_icon=False, parent=None):
     """Create a QToolButton directly from a QAction object"""
     if parent is None:
@@ -151,6 +171,7 @@ def action2button(action, autoraise=True, text_beside_icon=False, parent=None):
         button.setToolButtonStyle(Qt.ToolButtonTextBesideIcon)
     return button
 
+
 def toggle_actions(actions, enable):
     """Enable/disable actions"""
     if actions is not None:
@@ -158,6 +179,7 @@ def toggle_actions(actions, enable):
             if action is not None:
                 action.setEnabled(enable)
 
+
 def create_action(parent, text, shortcut=None, icon=None, tip=None,
                   toggled=None, triggered=None, data=None,
                   context=Qt.WindowShortcut):
@@ -178,13 +200,14 @@ def create_action(parent, text, shortcut=None, icon=None, tip=None,
         action.setToolTip(tip)
         action.setStatusTip(tip)
     if data is not None:
-        action.setData(QVariant(data))
+        action.setData(to_qvariant(data))
     #TODO: Hard-code all shortcuts and choose context=Qt.WidgetShortcut
     # (this will avoid calling shortcuts from another dockwidget
     #  since the context thing doesn't work quite well with these widgets)
     action.setShortcutContext(context)
     return action
 
+
 def add_actions(target, actions, insert_before=None):
     """Add actions to a menu"""
     previous_action = None
@@ -214,23 +237,21 @@ def add_actions(target, actions, insert_before=None):
 
 def get_item_user_text(item):
     """Get QTreeWidgetItem user role string"""
-    return unicode(item.data(0, Qt.UserRole).toString())
+    return from_qvariant(item.data(0, Qt.UserRole), unicode)
+
 
 def set_item_user_text(item, text):
     """Set QTreeWidgetItem user role string"""
-    item.setData(0, Qt.UserRole, QVariant(text))
+    item.setData(0, Qt.UserRole, to_qvariant(text))
 
 
 def create_bookmark_action(parent, url, title, icon=None, shortcut=None):
     """Create bookmark action"""
     if icon is None:
         icon = get_icon('browser.png')
-    if os.name == 'nt':
-        callback = os.startfile
-    else:
-        callback = webbrowser.open
     return create_action( parent, title, shortcut=shortcut, icon=icon,
-                          triggered=lambda u=url: callback(u) )
+                          triggered=lambda u=url: programs.start_file(u) )
+
 
 def create_module_bookmark_actions(parent, bookmarks):
     """
@@ -243,18 +264,19 @@ def create_module_bookmark_actions(parent, bookmarks):
             act = create_bookmark_action(parent, url, title, get_icon(icon))
             actions.append(act)
     return actions
+
         
 def create_program_action(parent, text, icon, name, nt_name=None):
     """Create action to run a program"""
-    if os.name == 'nt':
-        if nt_name is not None:
-            name = nt_name
-        name = programs.get_nt_program_name(name)
     if isinstance(icon, basestring):
         icon = get_icon(icon)
-    if programs.is_program_installed(name):
+    if os.name == 'nt' and nt_name is not None:
+        name = nt_name
+    path = programs.find_program(name)
+    if path is not None:
         return create_action(parent, text, icon=icon,
                              triggered=lambda: programs.run_program(name))
+
         
 def create_python_script_action(parent, text, icon, package, module, args=[]):
     """Create action to run a GUI based Python script"""
@@ -312,6 +334,7 @@ def get_std_icon(name, size=None):
     else:
         return QIcon( icon.pixmap(size, size) )
 
+
 def get_filetype_icon(fname):
     """Return file type icon"""
     ext = osp.splitext(fname)[1]
@@ -347,6 +370,7 @@ class ShowStdIcons(QWidget):
         self.setWindowTitle('Standard Platform Icons')
         self.setWindowIcon(get_std_icon('TitleBarMenuButton'))
 
+
 def show_std_icons():
     """
     Show all standard Icons
@@ -357,5 +381,6 @@ def show_std_icons():
     import sys
     sys.exit(app.exec_())
 
+
 if __name__ == "__main__":
     show_std_icons()
\ No newline at end of file
