@@ -14,13 +14,15 @@ from spyderlib.qt.QtGui import (QTableView, QVBoxLayout, QHBoxLayout,
                                 QSizePolicy, QCheckBox, QColor, QRadioButton,
                                 QLineEdit, QFrame, QMenu, QIntValidator,
                                 QGroupBox, QMessageBox)
-from spyderlib.qt.QtCore import (Qt, QVariant, QModelIndex, QAbstractTableModel,
-                                 SIGNAL, SLOT, QString, pyqtSignature)
+from spyderlib.qt.QtCore import (Qt, QModelIndex, QAbstractTableModel,
+                                 SIGNAL, SLOT, Slot)
+from spyderlib.qt.compat import to_qvariant
 
 from functools import partial as ft_partial
 
 # Local import
-from spyderlib.config import get_icon, _
+from spyderlib.baseconfig import _
+from spyderlib.config import get_icon
 from spyderlib.utils.qthelpers import add_actions, create_action
 
 def try_to_parse(value):
@@ -235,13 +237,13 @@ class ContentsWidget(QWidget):
         """Return comment string"""
         return unicode(self.comments_edt.text())
 
-    @pyqtSignature("bool")
+    @Slot(bool)
     def set_as_data(self, as_data):
         """Set if data type conversion"""
         self._as_data = as_data
         self.emit(SIGNAL("asDataChanged(bool)"), as_data)
 
-    @pyqtSignature("bool")
+    @Slot(bool)
     def set_as_code(self, as_code):
         """Set if code type conversion"""
         self._as_code = as_code
@@ -262,19 +264,19 @@ class PreviewTableModel(QAbstractTableModel):
 
     def _display_data(self, index):
         """Return a data element"""
-        return QVariant(self._data[index.row()][index.column()])
+        return to_qvariant(self._data[index.row()][index.column()])
     
     def data(self, index, role=Qt.DisplayRole):
         """Return a model data element"""
         if not index.isValid():
-            return QVariant()
+            return to_qvariant()
         if role == Qt.DisplayRole:
             return self._display_data(index)
         elif role == Qt.BackgroundColorRole:
-            return QVariant(get_color(self._data[index.row()][index.column()], .2))            
+            return to_qvariant(get_color(self._data[index.row()][index.column()], .2))            
         elif role == Qt.TextAlignmentRole:
-            return QVariant(int(Qt.AlignRight|Qt.AlignVCenter))
-        return QVariant()
+            return to_qvariant(int(Qt.AlignRight|Qt.AlignVCenter))
+        return to_qvariant()
     
     def setData(self, index, value, role=Qt.EditRole):
         """Set model data"""
@@ -358,7 +360,7 @@ class PreviewTable(QTableView):
             stripped = unicode(row).strip()
             if len(stripped) == 0 or stripped.startswith(comments):
                 continue
-            line = QString(row).split(colsep)
+            line = unicode(row).split(colsep)
             line = map(lambda x: try_to_parse(unicode(x)), line)
             out.append(line)
         if transpose:
@@ -429,6 +431,12 @@ class ImportWizard(QDialog):
                  title=None, icon=None, contents_title=None, varname=None):
         QDialog.__init__(self, parent)
         
+        # Destroying the C++ object right after closing the dialog box,
+        # otherwise it may be garbage-collected in another QThread
+        # (e.g. the editor's analysis thread in Spyder), thus leading to
+        # a segmentation fault on UNIX or an application crash on Windows
+        self.setAttribute(Qt.WA_DeleteOnClose)
+        
         if title is None:
             title = _("Import wizard")
         self.setWindowTitle(title)
@@ -534,6 +542,8 @@ class ImportWizard(QDialog):
     
     def get_data(self):
         """Return processed data"""
+        # It is import to avoid accessing Qt C++ object as it has probably
+        # already been destroyed, due to the Qt.WA_DeleteOnClose attribute
         return self.var_name, self.clip_data
 
     def _simplify_shape(self, alist, rec=0):
@@ -558,7 +568,7 @@ class ImportWizard(QDialog):
         """Return clipboard as text"""
         return self.text_widget.text_editor.toPlainText()
 
-    @pyqtSignature("")
+    @Slot()
     def process(self):
         """Process the data from clipboard"""
         var_name = self.name_edt.text()
@@ -585,4 +595,4 @@ def test(text):
         print dialog.get_data()
 
 if __name__ == "__main__":
-    test(QString(u"17/11/1976\t1.34\n14/05/09\t3.14"))
+    test(u"17/11/1976\t1.34\n14/05/09\t3.14")
